@@ -16,10 +16,6 @@ See L<Net::ISC::DHCPd::Config> for synopsis.
 =cut
 
 use Moose;
-use Net::ISC::DHCPd::Config::Subnet;
-use Net::ISC::DHCPd::Config::Host;
-use Net::ISC::DHCPd::Config::Option;
-use Net::ISC::DHCPd::Config::KeyValue;
 
 with 'Net::ISC::DHCPd::Config::Role';
 
@@ -29,7 +25,7 @@ __PACKAGE__->create_children(qw/
     Net::ISC::DHCPd::Config::KeyValue
 /);
 
-=head1 OBJECT ATTRIBUTES
+=head1 ATTRIBUTES
 
 =head2 subnets
 
@@ -43,26 +39,22 @@ A list of parsed L<Net::ISC::DHCPd::Config::Host> objects.
 
 A list of parsed L<Net::ISC::DHCPd::Config::Option> objects.
 
-=head2 regex
-
 =cut
 
-has '+regex' => (
-    default => sub { qr{^ \s* group}x },
-);
+sub _build_regex { qr{^ \s* group}x }
 
 =head2 generate
 
+See L<Net::ISC::DHCPd::Config::Role::generate()>.
+
 =cut
 
 sub generate {
-    return(
-        'group {',
-        shift->generate_config_from_children,
-        '}',
-    );
+    return 'group {', shift->generate_config_from_children, '}';
 }
 
+=head1 COPYRIGHT & LICENSE
+
 =head1 AUTHOR
 
 See L<Net::ISC::DHCPd>.
