@@ -19,7 +19,7 @@ use Moose;
 
 with 'Net::ISC::DHCPd::Config::Role';
 
-=head1 OBJECT ATTRIBUTES
+=head1 ATTRIBUTES
 
 =head2 name
 
@@ -60,18 +60,14 @@ has quoted => (
     isa => 'Bool',
 );
 
-=head2 regex
-
-=cut
-
-has '+regex' => (
-    default => sub { qr{^\s* ([\w-]+) \s (.*) ;}x },
-);
+sub _build_regex { qr{^\s* ([\w-]+) \s (.*) ;}x }
 
 =head1 METHODS
 
 =head2 captured_to_args
 
+See L<Net::ISC::DHCPd::Config::Role::captured_to_args()>.
+
 =cut
 
 sub captured_to_args {
@@ -91,19 +87,19 @@ sub captured_to_args {
 
 =head2 generate
 
+See L<Net::ISC::DHCPd::Config::Role::generate()>.
+
 =cut
 
 sub generate {
     my $self  = shift;
+    my $format = $self->quoted ? qq(%s "%s";) : qq(%s %s;);
 
-    if($self->quoted) {
-        return sprintf qq(%s "%s";), $self->name, $self->value;
-    }
-    else {
-        return sprintf qq(%s %s;), $self->name, $self->value;
-    }
+    return sprintf $format, $self->name, $self->value;
 }
 
+=head1 COPYRIGHT & LICENSE
+
 =head1 AUTHOR
 
 See L<Net::ISC::DHCPd>.
