@@ -16,7 +16,6 @@ See L<Net::ISC::DHCPd::Config> for synopsis.
 =cut
 
 use Moose;
-use Net::ISC::DHCPd::Config::OptionSpace::Option;
 
 with 'Net::ISC::DHCPd::Config::Role';
 
@@ -24,7 +23,7 @@ __PACKAGE__->create_children(qw/
     Net::ISC::DHCPd::Config::OptionSpace::Option
 /);
 
-=head1 OBJECT ATTRIBUTES
+=head1 ATTRIBUTES
 
 =head2 options
 
@@ -70,32 +69,22 @@ has prefix => (
     isa => 'Str',
 );
 
-=head2 regex
+sub _build_regex { qr{^\s* option \s space \s (.*) ;}x }
 
-=cut
-
-has '+regex' => (
-    default => sub { qr{^\s* option \s space \s (.*) ;}x },
-);
-
-=head2 endpoint
-
-=cut
-
-has '+endpoint' => (
-    default => sub {
-        qr{^
-            \s* option \s (\S+)
-            \s  code \s (\d+) \s =
-            \s  encapsulate \s (\S+) ;
-        }x;
-    },
-);
+sub _build_endpoint {
+    qr{^
+        \s* option \s (\S+)
+        \s  code \s (\d+) \s =
+        \s  encapsulate \s (\S+) ;
+    }x;
+}
 
 =head1 METHODS
 
 =head2 captured_to_args
 
+See L<Net::ISC::DHCPd::Config::Role::captured_to_args()>.
+
 =cut
 
 sub captured_to_args {
@@ -104,6 +93,8 @@ sub captured_to_args {
 
 =head2 captured_endpoint
 
+See L<Net::ISC::DHCPd::Config::Role::captured_endpoint()>.
+
 =cut
 
 sub captured_endpoint {
@@ -119,6 +110,8 @@ sub captured_endpoint {
 
 =head2 generate
 
+See L<Net::ISC::DHCPd::Config::Role::generate()>.
+
 =cut
 
 sub generate {
@@ -135,6 +128,8 @@ sub generate {
     );
 }
 
+=head1 COPYRIGHT & LICENSE
+
 =head1 AUTHOR
 
 See L<Net::ISC::DHCPd>.
