@@ -16,9 +16,6 @@ See L<Net::ISC::DHCPd::Config> for synopsis.
 =cut
 
 use Moose;
-use Net::ISC::DHCPd::Config::Option;
-use Net::ISC::DHCPd::Config::Range;
-use Net::ISC::DHCPd::Config::KeyValue;
 
 with 'Net::ISC::DHCPd::Config::Role';
 
@@ -28,7 +25,7 @@ __PACKAGE__->create_children(qw/
     Net::ISC::DHCPd::Config::KeyValue
 /);
 
-=head1 OBJECT ATTRIBUTES
+=head1 ATTRIBUTES
 
 =head2 options
 
@@ -38,28 +35,24 @@ A list of parsed L<Net::ISC::DHCPd::Config::Option> objects.
 
 A list of parsed L<Net::ISC::DHCPd::Config::Range> objects.
 
-=head2 regex
-
 =cut
 
-has '+regex' => (
-    default => sub { qr{^ \s* pool}x },
-);
+sub _build_regex { qr{^ \s* pool}x }
 
 =head1 METHODS
 
 =head2 generate
 
+See L<Net::ISC::DHCPd::Config::Role::generate()>.
+
 =cut
 
 sub generate {
-    return(
-        'pool {',
-        shift->generate_config_from_children,
-        '}',
-    );
+    return 'pool {', shift->generate_config_from_children, '}';
 }
 
+=head1 COPYRIGHT & LICENSE
+
 =head1 AUTHOR
 
 See L<Net::ISC::DHCPd>.
